@@ -31,7 +31,7 @@ class BadCampaignError(Error):
 
 class Client(object):
     """Contains functions to access the Yandex API."""
-    def __init__(self, application_id, login, auth_token, sandbox=False, password=None, debug=False, timeout=3600, logger=None):
+    def __init__(self, application_id, login, auth_token, sandbox=False, password=None, timeout=3600, logger=None):
         self.application_id = application_id
         self.application_password = password
         self.login = login
@@ -51,7 +51,7 @@ class Client(object):
 
                 data = json.loads(self._fetch(self._get_api_root(method), json.dumps(payload)))
                 if type(data) != dict:
-                    logging.error("Got %s instead of a dict: %s" % (type(data), data))
+                    self.logger.error("Got %s instead of a dict: %s" % (type(data), data))
                     enigma.error(500, "Could not interpret a Yandex.API response.")
 
                 if "error_code" in data:
@@ -72,7 +72,7 @@ class Client(object):
                 raise
             except Exception, e:
                 delay = 5 * (attempt + 1)
-                logging.exception("Error, will retry in %u seconds: %s" % (delay, e))
+                self.logger.exception("Error, will retry in %u seconds: %s" % (delay, e))
                 time.sleep(delay)
 
         raise e
@@ -129,7 +129,7 @@ class Client(object):
                 self.auth_token = token
             return self.call_method("PingAPI") == 1
         except Exception, e:
-            logging.error("Could not ping the API: %s" % e)
+            self.logger.error("Could not ping the API: %s" % e)
             return False
         finally:
             self.login = old_login
@@ -227,11 +227,11 @@ class Client(object):
             self.call_method("UpdatePrices", payload)
 
     def StopCampaign(self, CampaignID):
-        logging.info("Stopping campaign %s" % CampaignID)
+        self.logger.info("Stopping campaign %s" % CampaignID)
         self.call_method("StopCampaign", {"CampaignID": CampaignID})
 
     def ResumeCampaign(self, CampaignID):
-        logging.info("Resuming campaign %s" % CampaignID)
+        self.logger.info("Resuming campaign %s" % CampaignID)
         self.call_method("ResumeCampaign", {"CampaignID": CampaignID})
 
     def GetCampaignParams(self, CampaignID):
